/* SPDX-License-Identifier: (LGPL-2.1 OR BSD-2-Clause) */

/* THIS FILE IS AUTOGENERATED BY BPFTOOL! */
#ifndef __LOCAL_STORAGE_SKEL_H__
#define __LOCAL_STORAGE_SKEL_H__

#include <errno.h>
#include <stdlib.h>
#include <bpf/libbpf.h>

struct local_storage {
	struct bpf_object_skeleton *skeleton;
	struct bpf_object *obj;
	struct {
		struct bpf_map *inode_storage_map;
		struct bpf_map *sk_storage_map;
		struct bpf_map *sk_storage_map2;
		struct bpf_map *task_storage_map;
		struct bpf_map *bss;
		struct bpf_map *data;
	} maps;
	struct {
		struct bpf_program *unlink_hook;
		struct bpf_program *inode_rename;
		struct bpf_program *socket_bind;
		struct bpf_program *socket_post_create;
		struct bpf_program *exec;
	} progs;
	struct {
		struct bpf_link *unlink_hook;
		struct bpf_link *inode_rename;
		struct bpf_link *socket_bind;
		struct bpf_link *socket_post_create;
		struct bpf_link *exec;
	} links;
	struct local_storage__bss {
		int monitored_pid;
	} *bss;
	struct local_storage__data {
		int inode_storage_result;
		int sk_storage_result;
	} *data;

#ifdef __cplusplus
	static inline struct local_storage *open(const struct bpf_object_open_opts *opts = nullptr);
	static inline struct local_storage *open_and_load();
	static inline int load(struct local_storage *skel);
	static inline int attach(struct local_storage *skel);
	static inline void detach(struct local_storage *skel);
	static inline void destroy(struct local_storage *skel);
	static inline const void *elf_bytes(size_t *sz);
#endif /* __cplusplus */
};

static void
local_storage__destroy(struct local_storage *obj)
{
	if (!obj)
		return;
	if (obj->skeleton)
		bpf_object__destroy_skeleton(obj->skeleton);
	free(obj);
}

static inline int
local_storage__create_skeleton(struct local_storage *obj);

static inline struct local_storage *
local_storage__open_opts(const struct bpf_object_open_opts *opts)
{
	struct local_storage *obj;
	int err;

	obj = (struct local_storage *)calloc(1, sizeof(*obj));
	if (!obj) {
		errno = ENOMEM;
		return NULL;
	}

	err = local_storage__create_skeleton(obj);
	if (err)
		goto err_out;

	err = bpf_object__open_skeleton(obj->skeleton, opts);
	if (err)
		goto err_out;

	return obj;
err_out:
	local_storage__destroy(obj);
	errno = -err;
	return NULL;
}

static inline struct local_storage *
local_storage__open(void)
{
	return local_storage__open_opts(NULL);
}

static inline int
local_storage__load(struct local_storage *obj)
{
	return bpf_object__load_skeleton(obj->skeleton);
}

static inline struct local_storage *
local_storage__open_and_load(void)
{
	struct local_storage *obj;
	int err;

	obj = local_storage__open();
	if (!obj)
		return NULL;
	err = local_storage__load(obj);
	if (err) {
		local_storage__destroy(obj);
		errno = -err;
		return NULL;
	}
	return obj;
}

static inline int
local_storage__attach(struct local_storage *obj)
{
	return bpf_object__attach_skeleton(obj->skeleton);
}

static inline void
local_storage__detach(struct local_storage *obj)
{
	bpf_object__detach_skeleton(obj->skeleton);
}

static inline const void *local_storage__elf_bytes(size_t *sz);

static inline int
local_storage__create_skeleton(struct local_storage *obj)
{
	struct bpf_object_skeleton *s;
	int err;

	s = (struct bpf_object_skeleton *)calloc(1, sizeof(*s));
	if (!s)	{
		err = -ENOMEM;
		goto err;
	}

	s->sz = sizeof(*s);
	s->name = "local_storage";
	s->obj = &obj->obj;

	/* maps */
	s->map_cnt = 6;
	s->map_skel_sz = sizeof(*s->maps);
	s->maps = (struct bpf_map_skeleton *)calloc(s->map_cnt, s->map_skel_sz);
	if (!s->maps) {
		err = -ENOMEM;
		goto err;
	}

	s->maps[0].name = "inode_storage_map";
	s->maps[0].map = &obj->maps.inode_storage_map;

	s->maps[1].name = "sk_storage_map";
	s->maps[1].map = &obj->maps.sk_storage_map;

	s->maps[2].name = "sk_storage_map2";
	s->maps[2].map = &obj->maps.sk_storage_map2;

	s->maps[3].name = "task_storage_map";
	s->maps[3].map = &obj->maps.task_storage_map;

	s->maps[4].name = "local_st.bss";
	s->maps[4].map = &obj->maps.bss;
	s->maps[4].mmaped = (void **)&obj->bss;

	s->maps[5].name = "local_st.data";
	s->maps[5].map = &obj->maps.data;
	s->maps[5].mmaped = (void **)&obj->data;

	/* programs */
	s->prog_cnt = 5;
	s->prog_skel_sz = sizeof(*s->progs);
	s->progs = (struct bpf_prog_skeleton *)calloc(s->prog_cnt, s->prog_skel_sz);
	if (!s->progs) {
		err = -ENOMEM;
		goto err;
	}

	s->progs[0].name = "unlink_hook";
	s->progs[0].prog = &obj->progs.unlink_hook;
	s->progs[0].link = &obj->links.unlink_hook;

	s->progs[1].name = "inode_rename";
	s->progs[1].prog = &obj->progs.inode_rename;
	s->progs[1].link = &obj->links.inode_rename;

	s->progs[2].name = "socket_bind";
	s->progs[2].prog = &obj->progs.socket_bind;
	s->progs[2].link = &obj->links.socket_bind;

	s->progs[3].name = "socket_post_create";
	s->progs[3].prog = &obj->progs.socket_post_create;
	s->progs[3].link = &obj->links.socket_post_create;

	s->progs[4].name = "exec";
	s->progs[4].prog = &obj->progs.exec;
	s->progs[4].link = &obj->links.exec;

	s->data = (void *)local_storage__elf_bytes(&s->data_sz);

	obj->skeleton = s;
	return 0;
err:
	bpf_object__destroy_skeleton(s);
	return err;
}

static inline const void *local_storage__elf_bytes(size_t *sz)
{
	*sz = 14168;
	return (const void *)"\
\x7f\x45\x4c\x46\x02\x01\x01\0\0\0\0\0\0\0\0\0\x01\0\xf7\0\x01\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\x98\x32\0\0\0\0\0\0\0\0\0\0\x40\0\0\0\0\0\x40\0\x13\0\
\x01\0\0\x2e\x73\x74\x72\x74\x61\x62\0\x2e\x73\x79\x6d\x74\x61\x62\0\x6c\x73\
\x6d\x2f\x69\x6e\x6f\x64\x65\x5f\x75\x6e\x6c\x69\x6e\x6b\0\x6c\x73\x6d\x2e\x73\
\x2f\x69\x6e\x6f\x64\x65\x5f\x72\x65\x6e\x61\x6d\x65\0\x6c\x73\x6d\x2e\x73\x2f\
\x73\x6f\x63\x6b\x65\x74\x5f\x62\x69\x6e\x64\0\x6c\x73\x6d\x2e\x73\x2f\x73\x6f\
\x63\x6b\x65\x74\x5f\x70\x6f\x73\x74\x5f\x63\x72\x65\x61\x74\x65\0\x6c\x73\x6d\
\x2e\x73\x2f\x62\x70\x72\x6d\x5f\x63\x6f\x6d\x6d\x69\x74\x74\x65\x64\x5f\x63\
\x72\x65\x64\x73\0\x6c\x69\x63\x65\x6e\x73\x65\0\x2e\x62\x73\x73\0\x2e\x64\x61\
\x74\x61\0\x2e\x6d\x61\x70\x73\0\x6c\x6f\x63\x61\x6c\x5f\x73\x74\x6f\x72\x61\
\x67\x65\x2e\x63\0\x4c\x42\x42\x30\x5f\x34\0\x4c\x42\x42\x30\x5f\x33\0\x4c\x42\
\x42\x31\x5f\x35\0\x4c\x42\x42\x31\x5f\x33\0\x4c\x42\x42\x32\x5f\x38\0\x4c\x42\
\x42\x32\x5f\x34\0\x4c\x42\x42\x33\x5f\x33\0\x4c\x42\x42\x34\x5f\x35\0\x4c\x42\
\x42\x34\x5f\x33\0\x75\x6e\x6c\x69\x6e\x6b\x5f\x68\x6f\x6f\x6b\0\x6d\x6f\x6e\
\x69\x74\x6f\x72\x65\x64\x5f\x70\x69\x64\0\x74\x61\x73\x6b\x5f\x73\x74\x6f\x72\
\x61\x67\x65\x5f\x6d\x61\x70\0\x69\x6e\x6f\x64\x65\x5f\x72\x65\x6e\x61\x6d\x65\
\0\x69\x6e\x6f\x64\x65\x5f\x73\x74\x6f\x72\x61\x67\x65\x5f\x6d\x61\x70\0\x69\
\x6e\x6f\x64\x65\x5f\x73\x74\x6f\x72\x61\x67\x65\x5f\x72\x65\x73\x75\x6c\x74\0\
\x73\x6f\x63\x6b\x65\x74\x5f\x62\x69\x6e\x64\0\x73\x6b\x5f\x73\x74\x6f\x72\x61\
\x67\x65\x5f\x6d\x61\x70\0\x73\x6b\x5f\x73\x74\x6f\x72\x61\x67\x65\x5f\x72\x65\
\x73\x75\x6c\x74\0\x73\x6b\x5f\x73\x74\x6f\x72\x61\x67\x65\x5f\x6d\x61\x70\x32\
\0\x73\x6f\x63\x6b\x65\x74\x5f\x70\x6f\x73\x74\x5f\x63\x72\x65\x61\x74\x65\0\
\x65\x78\x65\x63\0\x5f\x6c\x69\x63\x65\x6e\x73\x65\0\x2e\x72\x65\x6c\x6c\x73\
\x6d\x2f\x69\x6e\x6f\x64\x65\x5f\x75\x6e\x6c\x69\x6e\x6b\0\x2e\x72\x65\x6c\x6c\
\x73\x6d\x2e\x73\x2f\x69\x6e\x6f\x64\x65\x5f\x72\x65\x6e\x61\x6d\x65\0\x2e\x72\
\x65\x6c\x6c\x73\x6d\x2e\x73\x2f\x73\x6f\x63\x6b\x65\x74\x5f\x62\x69\x6e\x64\0\
\x2e\x72\x65\x6c\x6c\x73\x6d\x2e\x73\x2f\x73\x6f\x63\x6b\x65\x74\x5f\x70\x6f\
\x73\x74\x5f\x63\x72\x65\x61\x74\x65\0\x2e\x72\x65\x6c\x6c\x73\x6d\x2e\x73\x2f\
\x62\x70\x72\x6d\x5f\x63\x6f\x6d\x6d\x69\x74\x74\x65\x64\x5f\x63\x72\x65\x64\
\x73\0\x2e\x42\x54\x46\0\x2e\x42\x54\x46\x2e\x65\x78\x74\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x94\0\0\0\x04\0\xf1\xff\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\x03\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xa4\0\0\0\0\
\0\x03\0\xb0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xab\0\0\0\0\0\x03\0\xa8\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xb2\0\0\
\0\0\0\x04\0\x20\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xb9\0\0\0\0\0\x04\0\xc8\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\x05\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\xc0\0\0\0\0\0\x05\0\x80\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xc7\0\0\0\0\0\x05\0\
\xb8\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\xce\0\0\0\0\0\x06\0\x88\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\
\x07\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xd5\0\0\0\0\0\x07\0\xe8\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\xdc\0\0\0\0\0\x07\0\x90\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xe3\0\0\0\
\x12\0\x03\0\0\0\0\0\0\0\0\0\xc0\0\0\0\0\0\0\0\xef\0\0\0\x11\0\x09\0\0\0\0\0\0\
\0\0\0\x04\0\0\0\0\0\0\0\xfd\0\0\0\x11\0\x0b\0\x60\0\0\0\0\0\0\0\x20\0\0\0\0\0\
\0\0\x0e\x01\0\0\x12\0\x04\0\0\0\0\0\0\0\0\0\x30\x01\0\0\0\0\0\0\x1b\x01\0\0\
\x11\0\x0b\0\0\0\0\0\0\0\0\0\x20\0\0\0\0\0\0\0\x2d\x01\0\0\x11\0\x0a\0\0\0\0\0\
\0\0\0\0\x04\0\0\0\0\0\0\0\x42\x01\0\0\x12\0\x05\0\0\0\0\0\0\0\0\0\x90\x01\0\0\
\0\0\0\0\x4e\x01\0\0\x11\0\x0b\0\x20\0\0\0\0\0\0\0\x20\0\0\0\0\0\0\0\x5d\x01\0\
\0\x11\0\x0a\0\x04\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\x6f\x01\0\0\x11\0\x0b\0\x40\
\0\0\0\0\0\0\0\x20\0\0\0\0\0\0\0\x7f\x01\0\0\x12\0\x06\0\0\0\0\0\0\0\0\0\x98\0\
\0\0\0\0\0\0\x92\x01\0\0\x12\0\x07\0\0\0\0\0\0\0\0\0\xf0\0\0\0\0\0\0\0\x97\x01\
\0\0\x11\0\x08\0\0\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\xb7\x06\0\0\0\0\0\0\x79\x17\
\x08\0\0\0\0\0\x85\0\0\0\x0e\0\0\0\x77\0\0\0\x20\0\0\0\x18\x01\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\x61\x11\0\0\0\0\0\0\x5d\x01\x0e\0\0\0\0\0\x85\0\0\0\x9e\0\0\0\x18\
\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xbf\x02\0\0\0\0\0\0\xb7\x03\0\0\0\0\0\0\xb7\
\x04\0\0\0\0\0\0\x85\0\0\0\x9c\0\0\0\x15\0\x05\0\0\0\0\0\x18\x06\0\0\xff\xff\
\xff\xff\0\0\0\0\0\0\0\0\x79\x71\x30\0\0\0\0\0\x79\x02\0\0\0\0\0\0\x1d\x12\x01\
\0\0\0\0\0\xb7\x06\0\0\0\0\0\0\xbf\x60\0\0\0\0\0\0\x95\0\0\0\0\0\0\0\x79\x16\
\x08\0\0\0\0\0\x79\x17\x18\0\0\0\0\0\x85\0\0\0\x0e\0\0\0\x79\x72\x30\0\0\0\0\0\
\x18\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xb7\x03\0\0\0\0\0\0\xb7\x04\0\0\x01\0\0\0\
\x85\0\0\0\x91\0\0\0\x79\x62\x30\0\0\0\0\0\x18\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\xb7\x03\0\0\0\0\0\0\xb7\x04\0\0\0\0\0\0\x85\0\0\0\x91\0\0\0\x15\0\x14\0\0\0\0\
\0\x61\x01\x08\0\0\0\0\0\x18\x02\0\0\xef\xbe\xad\xde\0\0\0\0\0\0\0\0\x1d\x21\
\x05\0\0\0\0\0\x18\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x18\x02\0\0\xff\xff\xff\xff\
\0\0\0\0\0\0\0\0\x63\x21\0\0\0\0\0\0\x79\x62\x30\0\0\0\0\0\x18\x01\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\x85\0\0\0\x92\0\0\0\x67\0\0\0\x20\0\0\0\x77\0\0\0\x20\0\0\0\
\x55\0\x04\0\0\0\0\0\x18\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xb7\x02\0\0\0\0\0\0\
\x63\x21\0\0\0\0\0\0\xb7\0\0\0\0\0\0\0\x95\0\0\0\0\0\0\0\x79\x16\0\0\0\0\0\0\
\x85\0\0\0\x0e\0\0\0\x77\0\0\0\x20\0\0\0\x18\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x61\x11\0\0\0\0\0\0\x5d\x01\x29\0\0\0\0\0\x79\x62\x18\0\0\0\0\0\x18\x01\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\xb7\x03\0\0\0\0\0\0\xb7\x04\0\0\x01\0\0\0\x85\0\0\0\x6b\
\0\0\0\x15\0\x22\0\0\0\0\0\x61\x01\x08\0\0\0\0\0\x18\x02\0\0\xef\xbe\xad\xde\0\
\0\0\0\0\0\0\0\x1d\x21\x05\0\0\0\0\0\x18\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x18\
\x02\0\0\xff\xff\xff\xff\0\0\0\0\0\0\0\0\x63\x21\0\0\0\0\0\0\x79\x62\x18\0\0\0\
\0\0\x18\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xb7\x03\0\0\0\0\0\0\xb7\x04\0\0\x01\0\
\0\0\x85\0\0\0\x6b\0\0\0\x15\0\x12\0\0\0\0\0\x79\x62\x18\0\0\0\0\0\x18\x01\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\x85\0\0\0\x6c\0\0\0\x67\0\0\0\x20\0\0\0\x77\0\0\0\x20\
\0\0\0\x55\0\x0b\0\0\0\0\0\x79\x62\x18\0\0\0\0\0\x18\x01\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\x85\0\0\0\x6c\0\0\0\x67\0\0\0\x20\0\0\0\x77\0\0\0\x20\0\0\0\x55\0\x04\0\
\0\0\0\0\x18\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xb7\x02\0\0\0\0\0\0\x63\x21\0\0\0\
\0\0\0\xb7\0\0\0\0\0\0\0\x95\0\0\0\0\0\0\0\x79\x16\0\0\0\0\0\0\x85\0\0\0\x0e\0\
\0\0\x77\0\0\0\x20\0\0\0\x18\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x61\x11\0\0\0\0\0\
\0\x5d\x01\x0a\0\0\0\0\0\x79\x62\x18\0\0\0\0\0\x18\x01\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\xb7\x03\0\0\0\0\0\0\xb7\x04\0\0\x01\0\0\0\x85\0\0\0\x6b\0\0\0\x15\0\x03\0\
\0\0\0\0\x18\x01\0\0\xef\xbe\xad\xde\0\0\0\0\0\0\0\0\x63\x10\x08\0\0\0\0\0\xb7\
\0\0\0\0\0\0\0\x95\0\0\0\0\0\0\0\x79\x16\0\0\0\0\0\0\x85\0\0\0\x0e\0\0\0\x77\0\
\0\0\x20\0\0\0\x18\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x61\x11\0\0\0\0\0\0\x5d\x01\
\x16\0\0\0\0\0\x85\0\0\0\x9e\0\0\0\x18\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xbf\x02\
\0\0\0\0\0\0\xb7\x03\0\0\0\0\0\0\xb7\x04\0\0\x01\0\0\0\x85\0\0\0\x9c\0\0\0\x15\
\0\x03\0\0\0\0\0\x79\x61\x40\0\0\0\0\0\x79\x11\x20\0\0\0\0\0\x7b\x10\0\0\0\0\0\
\0\x79\x61\x40\0\0\0\0\0\x79\x12\x20\0\0\0\0\0\x18\x01\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\xb7\x03\0\0\0\0\0\0\xb7\x04\0\0\x01\0\0\0\x85\0\0\0\x91\0\0\0\x15\0\x03\0\
\0\0\0\0\x18\x01\0\0\xef\xbe\xad\xde\0\0\0\0\0\0\0\0\x63\x10\x08\0\0\0\0\0\x95\
\0\0\0\0\0\0\0\x47\x50\x4c\0\xff\xff\xff\xff\xff\xff\xff\xff\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\x20\0\0\0\0\0\0\0\x01\0\0\0\x11\0\0\0\x48\0\0\0\0\0\0\0\x01\0\0\0\
\x12\0\0\0\x20\0\0\0\0\0\0\0\x01\0\0\0\x14\0\0\0\x50\0\0\0\0\0\0\0\x01\0\0\0\
\x14\0\0\0\xa0\0\0\0\0\0\0\0\x01\0\0\0\x15\0\0\0\xd0\0\0\0\0\0\0\0\x01\0\0\0\
\x14\0\0\0\0\x01\0\0\0\0\0\0\x01\0\0\0\x15\0\0\0\x18\0\0\0\0\0\0\0\x01\0\0\0\
\x11\0\0\0\x40\0\0\0\0\0\0\0\x01\0\0\0\x17\0\0\0\x90\0\0\0\0\0\0\0\x01\0\0\0\
\x18\0\0\0\xc0\0\0\0\0\0\0\0\x01\0\0\0\x19\0\0\0\xf8\0\0\0\0\0\0\0\x01\0\0\0\
\x17\0\0\0\x30\x01\0\0\0\0\0\0\x01\0\0\0\x19\0\0\0\x60\x01\0\0\0\0\0\0\x01\0\0\
\0\x18\0\0\0\x18\0\0\0\0\0\0\0\x01\0\0\0\x11\0\0\0\x40\0\0\0\0\0\0\0\x01\0\0\0\
\x17\0\0\0\x18\0\0\0\0\0\0\0\x01\0\0\0\x11\0\0\0\x40\0\0\0\0\0\0\0\x01\0\0\0\
\x12\0\0\0\xa0\0\0\0\0\0\0\0\x01\0\0\0\x14\0\0\0\x9f\xeb\x01\0\x18\0\0\0\0\0\0\
\0\x24\x11\0\0\x24\x11\0\0\xda\x0e\0\0\0\0\0\0\0\0\0\x02\x03\0\0\0\x01\0\0\0\0\
\0\0\x01\x04\0\0\0\x20\0\0\x01\0\0\0\0\0\0\0\x03\0\0\0\0\x02\0\0\0\x04\0\0\0\
\x1c\0\0\0\x05\0\0\0\0\0\0\x01\x04\0\0\0\x20\0\0\0\0\0\0\0\0\0\0\x02\x06\0\0\0\
\0\0\0\0\0\0\0\x03\0\0\0\0\x02\0\0\0\x04\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\x02\x02\
\0\0\0\0\0\0\0\0\0\0\x02\x09\0\0\0\x19\0\0\0\x02\0\0\x04\x10\0\0\0\x27\0\0\0\
\x0a\0\0\0\0\0\0\0\x32\0\0\0\x0b\0\0\0\x40\0\0\0\0\0\0\0\0\0\0\x02\x9d\0\0\0\
\x38\0\0\0\0\0\0\x08\x0c\0\0\0\x3e\0\0\0\0\0\0\x01\x04\0\0\0\x20\0\0\0\0\0\0\0\
\x04\0\0\x04\x20\0\0\0\x4b\0\0\0\x01\0\0\0\0\0\0\0\x50\0\0\0\x05\0\0\0\x40\0\0\
\0\x5a\0\0\0\x07\0\0\0\x80\0\0\0\x32\0\0\0\x08\0\0\0\xc0\0\0\0\x5e\0\0\0\0\0\0\
\x0e\x0d\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\x02\x10\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\0\
\x02\0\0\0\x04\0\0\0\x18\0\0\0\0\0\0\0\0\0\0\x02\x12\0\0\0\0\0\0\0\0\0\0\x03\0\
\0\0\0\x02\0\0\0\x04\0\0\0\x01\x02\0\0\0\0\0\0\x04\0\0\x04\x20\0\0\0\x4b\0\0\0\
\x0f\0\0\0\0\0\0\0\x50\0\0\0\x11\0\0\0\x40\0\0\0\x5a\0\0\0\x07\0\0\0\x80\0\0\0\
\x32\0\0\0\x08\0\0\0\xc0\0\0\0\x70\0\0\0\0\0\0\x0e\x13\0\0\0\x01\0\0\0\x7f\0\0\
\0\0\0\0\x0e\x13\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\x02\x17\0\0\0\0\0\0\0\0\0\0\x03\
\0\0\0\0\x02\0\0\0\x04\0\0\0\x1d\0\0\0\0\0\0\0\x04\0\0\x04\x20\0\0\0\x4b\0\0\0\
\x16\0\0\0\0\0\0\0\x50\0\0\0\x05\0\0\0\x40\0\0\0\x5a\0\0\0\x07\0\0\0\x80\0\0\0\
\x32\0\0\0\x08\0\0\0\xc0\0\0\0\x8f\0\0\0\0\0\0\x0e\x18\0\0\0\x01\0\0\0\0\0\0\0\
\0\0\0\x02\x1b\0\0\0\xa0\0\0\0\0\0\0\x01\x08\0\0\0\x40\0\0\0\0\0\0\0\x01\0\0\
\x0d\x02\0\0\0\xb3\0\0\0\x1a\0\0\0\xb7\0\0\0\x01\0\0\x0c\x1c\0\0\0\xc3\0\0\0\
\x10\0\0\x04\xc0\0\0\0\xca\0\0\0\x0c\0\0\0\0\0\0\0\xd2\0\0\0\x1f\0\0\0\x20\0\0\
\0\xd8\0\0\0\x23\0\0\0\x40\0\0\0\xdf\0\0\0\x26\0\0\0\xc0\0\0\0\xe8\0\0\0\x27\0\
\0\0\0\x01\0\0\xef\0\0\0\x0a\0\0\0\x80\x01\0\0\xf7\0\0\0\x30\0\0\0\xc0\x01\0\0\
\xff\0\0\0\x31\0\0\0\xc0\x02\0\0\x09\x01\0\0\x44\0\0\0\0\x03\0\0\x0e\x01\0\0\
\x46\0\0\0\x40\x03\0\0\x13\x01\0\0\x47\0\0\0\x80\x03\0\0\x1a\x01\0\0\x48\0\0\0\
\xc0\x03\0\0\0\0\0\0\x49\0\0\0\0\x04\0\0\x23\x01\0\0\x4a\0\0\0\x80\x04\0\0\x2b\
\x01\0\0\x4a\0\0\0\0\x05\0\0\x35\x01\0\0\x4e\0\0\0\x80\x05\0\0\x39\x01\0\0\0\0\
\0\x08\x20\0\0\0\x4d\x01\0\0\x01\0\0\x04\x04\0\0\0\x5f\x01\0\0\x21\0\0\0\0\0\0\
\0\x68\x01\0\0\0\0\0\x08\x22\0\0\0\x5f\x01\0\0\x01\0\0\x04\x04\0\0\0\x73\x01\0\
\0\x0c\0\0\0\0\0\0\0\x7c\x01\0\0\x02\0\0\x04\x10\0\0\0\x8a\x01\0\0\x24\0\0\0\0\
\0\0\0\x8f\x01\0\0\x25\0\0\0\x40\0\0\0\0\0\0\0\0\0\0\x02\x23\0\0\0\0\0\0\0\0\0\
\0\x02\x24\0\0\0\0\0\0\0\0\0\0\x02\x1e\0\0\0\x95\x01\0\0\x02\0\0\x04\x10\0\0\0\
\0\0\0\0\x28\0\0\0\0\0\0\0\x9a\x01\0\0\x2d\0\0\0\x40\0\0\0\0\0\0\0\x02\0\0\x05\
\x08\0\0\0\0\0\0\0\x29\0\0\0\0\0\0\0\x9f\x01\0\0\x2b\0\0\0\0\0\0\0\0\0\0\0\x02\
\0\0\x04\x08\0\0\0\xa8\x01\0\0\x2a\0\0\0\0\0\0\0\xad\x01\0\0\x2a\0\0\0\x20\0\0\
\0\xb1\x01\0\0\0\0\0\x08\x0b\0\0\0\xb5\x01\0\0\0\0\0\x08\x2c\0\0\0\xb9\x01\0\0\
\0\0\0\x08\x1b\0\0\0\0\0\0\0\0\0\0\x02\x2e\0\0\0\0\0\0\0\0\0\0\x0a\x2f\0\0\0\
\xbf\x01\0\0\0\0\0\x01\x01\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\0\x2f\0\0\0\
\x04\0\0\0\x20\0\0\0\xcd\x01\0\0\x01\0\0\x04\x08\0\0\0\0\0\0\0\x32\0\0\0\0\0\0\
\0\0\0\0\0\x02\0\0\x05\x08\0\0\0\xd5\x01\0\0\x2c\0\0\0\0\0\0\0\0\0\0\0\x33\0\0\
\0\0\0\0\0\0\0\0\0\x02\0\0\x04\x08\0\0\0\xe0\x01\0\0\x34\0\0\0\0\0\0\0\xe5\x01\
\0\0\x02\0\0\0\x20\0\0\0\xeb\x01\0\0\0\0\0\x08\x35\0\0\0\xf6\x01\0\0\x01\0\0\
\x04\x04\0\0\0\0\0\0\0\x36\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\x05\x04\0\0\0\xff\x01\
\0\0\x37\0\0\0\0\0\0\0\x05\x02\0\0\x01\0\0\x04\x04\0\0\0\x12\x02\0\0\x38\0\0\0\
\0\0\0\0\x1b\x02\0\0\0\0\0\x08\x39\0\0\0\x2b\x02\0\0\x01\0\0\x04\x04\0\0\0\0\0\
\0\0\x3a\0\0\0\0\0\0\0\0\0\0\0\x03\0\0\x05\x04\0\0\0\x35\x02\0\0\x3b\0\0\0\0\0\
\0\0\0\0\0\0\x3d\0\0\0\0\0\0\0\0\0\0\0\x40\0\0\0\0\0\0\0\x39\x02\0\0\0\0\0\x08\
\x3c\0\0\0\0\0\0\0\x01\0\0\x04\x04\0\0\0\x42\x02\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\
\x02\0\0\x04\x02\0\0\0\x4a\x02\0\0\x3e\0\0\0\0\0\0\0\x51\x02\0\0\x3e\0\0\0\x08\
\0\0\0\x59\x02\0\0\0\0\0\x08\x3f\0\0\0\x5c\x02\0\0\0\0\0\x08\x2f\0\0\0\0\0\0\0\
\x02\0\0\x04\x04\0\0\0\x61\x02\0\0\x41\0\0\0\0\0\0\0\x70\x02\0\0\x41\0\0\0\x10\
\0\0\0\x75\x02\0\0\0\0\0\x08\x42\0\0\0\x79\x02\0\0\0\0\0\x08\x43\0\0\0\x7f\x02\
\0\0\0\0\0\x01\x02\0\0\0\x10\0\0\0\0\0\0\0\0\0\0\x02\x45\0\0\0\0\0\0\0\0\0\0\
\x0a\x9e\0\0\0\0\0\0\0\0\0\0\x02\xa1\0\0\0\x8e\x02\0\0\0\0\0\x01\x08\0\0\0\x40\
\0\0\0\0\0\0\0\0\0\0\x02\0\0\0\0\0\0\0\0\x02\0\0\x05\x10\0\0\0\x9c\x02\0\0\x4a\
\0\0\0\0\0\0\0\xa2\x02\0\0\x4c\0\0\0\0\0\0\0\xa9\x02\0\0\x02\0\0\x04\x10\0\0\0\
\x8a\x01\0\0\x4b\0\0\0\0\0\0\0\xb3\x02\0\0\x4b\0\0\0\x40\0\0\0\0\0\0\0\0\0\0\
\x02\x4a\0\0\0\0\0\0\0\0\0\0\x02\x4d\0\0\0\xb8\x02\0\0\0\0\0\x08\x61\0\0\0\0\0\
\0\0\x03\0\0\x05\x10\0\0\0\xca\x02\0\0\x4f\0\0\0\0\0\0\0\xd2\x02\0\0\x23\0\0\0\
\0\0\0\0\xe3\x02\0\0\x52\0\0\0\0\0\0\0\xe9\x02\0\0\x02\0\0\x04\x10\0\0\0\x8a\
\x01\0\0\x50\0\0\0\0\0\0\0\x8f\x01\0\0\x51\0\0\0\x40\0\0\0\0\0\0\0\0\0\0\x02\
\x4f\0\0\0\0\0\0\0\0\0\0\x02\x50\0\0\0\xf4\x02\0\0\x02\0\0\x04\x10\0\0\0\x8a\
\x01\0\0\x53\0\0\0\0\0\0\0\x02\x03\0\0\x54\0\0\0\x40\0\0\0\0\0\0\0\0\0\0\x02\
\x52\0\0\0\0\0\0\0\0\0\0\x02\x55\0\0\0\0\0\0\0\x01\0\0\x0d\0\0\0\0\0\0\0\0\x53\
\0\0\0\x07\x03\0\0\x01\0\0\x0c\x1c\0\0\0\x14\x03\0\0\x01\0\0\x0c\x1c\0\0\0\x20\
\x03\0\0\x07\0\0\x04\0\x01\0\0\x27\x03\0\0\x59\0\0\0\0\0\0\0\x4b\0\0\0\x5b\0\0\
\0\x20\0\0\0\x2d\x03\0\0\x47\0\0\0\x40\0\0\0\x33\x03\0\0\x5c\0\0\0\x80\0\0\0\
\x38\x03\0\0\x5d\0\0\0\xc0\0\0\0\x3b\x03\0\0\x5e\0\0\0\0\x01\0\0\x3f\x03\0\0\
\x60\0\0\0\0\x04\0\0\x42\x03\0\0\0\0\0\x08\x5a\0\0\0\0\0\0\0\x05\0\0\x06\x04\0\
\0\0\x4f\x03\0\0\0\0\0\0\x57\x03\0\0\x01\0\0\0\x66\x03\0\0\x02\0\0\0\x74\x03\0\
\0\x03\0\0\0\x81\x03\0\0\x04\0\0\0\x92\x03\0\0\0\0\0\x01\x02\0\0\0\x10\0\0\x01\
\0\0\0\0\0\0\0\x02\x70\0\0\0\0\0\0\0\0\0\0\x02\xa8\0\0\0\0\0\0\0\0\0\0\x02\x5f\
\0\0\0\0\0\0\0\0\0\0\x0a\xaa\0\0\0\x98\x03\0\0\x04\0\0\x04\x80\0\0\0\xa2\x03\0\
\0\x4d\0\0\0\0\0\0\0\xa7\x03\0\0\x62\0\0\0\xc0\0\0\0\x2d\x03\0\0\x47\0\0\0\0\
\x01\0\0\xb3\x03\0\0\x52\0\0\0\x40\x01\0\0\xb7\x03\0\0\x02\0\0\x04\x18\0\0\0\
\xe0\x01\0\0\x34\0\0\0\0\0\0\0\xc7\x03\0\0\x4a\0\0\0\x40\0\0\0\0\0\0\0\0\0\0\
\x02\xa7\0\0\0\xcc\x03\0\0\x01\0\0\x0c\x1c\0\0\0\0\0\0\0\x01\0\0\x0d\0\0\0\0\
\xb3\0\0\0\x1a\0\0\0\xdf\x03\0\0\x01\0\0\x0c\x64\0\0\0\xe4\x03\0\0\x1a\0\0\x84\
\xa0\x01\0\0\xf1\x03\0\0\x67\0\0\0\0\0\0\0\xf5\x03\0\0\x47\0\0\0\x40\0\0\0\xff\
\x03\0\0\x68\0\0\0\x80\0\0\0\x02\x04\0\0\x47\0\0\0\xc0\0\0\0\x04\x04\0\0\x47\0\
\0\0\0\x01\0\0\x0b\x04\0\0\x0c\0\0\0\x40\x01\0\x01\x17\x04\0\0\x0c\0\0\0\x41\
\x01\0\x01\x24\x04\0\0\x0c\0\0\0\x42\x01\0\x01\x2f\x04\0\0\x0c\0\0\0\x43\x01\0\
\x01\x42\x04\0\0\x5c\0\0\0\x80\x01\0\0\x4d\x04\0\0\x5c\0\0\0\xc0\x01\0\0\x33\
\x03\0\0\x5c\0\0\0\0\x02\0\0\x59\x04\0\0\x69\0\0\0\x40\x02\0\0\x5e\x04\0\0\x02\
\0\0\0\x80\x02\0\0\x65\x04\0\0\x0c\0\0\0\xa0\x02\0\0\x6f\x04\0\0\x02\0\0\0\xc0\
\x02\0\0\x74\x04\0\0\x02\0\0\0\xe0\x02\0\0\x79\x04\0\0\x6a\0\0\0\0\x03\0\0\x82\
\x04\0\0\x6a\0\0\0\x40\x03\0\0\x89\x04\0\0\x6a\0\0\0\x80\x03\0\0\x90\x04\0\0\
\x0c\0\0\0\xc0\x03\0\0\x9d\x04\0\0\x02\0\0\0\xe0\x03\0\0\xa4\x04\0\0\x47\0\0\0\
\0\x04\0\0\xdf\x03\0\0\x47\0\0\0\x40\x04\0\0\xab\x04\0\0\x6d\0\0\0\x80\x04\0\0\
\xb6\x04\0\0\x6f\0\0\0\0\x05\0\0\0\0\0\0\0\0\0\x02\xa4\0\0\0\0\0\0\0\0\0\0\x02\
\xa3\0\0\0\0\0\0\0\0\0\0\x02\xa5\0\0\0\0\0\0\0\0\0\0\x02\x6b\0\0\0\0\0\0\0\0\0\
\0\x0a\x6c\0\0\0\xba\x04\0\0\0\0\0\x01\x01\0\0\0\x08\0\0\x01\xbf\x04\0\0\x02\0\
\0\x04\x10\0\0\0\xc6\x04\0\0\x6e\0\0\0\0\0\0\0\xcf\x04\0\0\x6e\0\0\0\x40\0\0\0\
\xd8\x04\0\0\0\0\0\x08\x47\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\0\x6c\0\0\0\x04\0\0\0\
\0\x01\0\0\x33\x03\0\0\x14\0\0\x04\xe8\0\0\0\xe9\x04\0\0\x71\0\0\0\0\0\0\0\xed\
\x04\0\0\x74\0\0\0\x80\0\0\0\xf4\x04\0\0\x0a\0\0\0\0\x01\0\0\xfc\x04\0\0\x76\0\
\0\0\x40\x01\0\0\x01\x05\0\0\x34\0\0\0\x80\x01\0\0\x08\x05\0\0\x78\0\0\0\xc0\
\x01\0\0\x10\x05\0\0\x0c\0\0\0\0\x02\0\0\x18\x05\0\0\x7e\0\0\0\x20\x02\0\0\x1f\
\x05\0\0\x7f\0\0\0\x40\x02\0\0\x2a\x05\0\0\x82\0\0\0\x40\x03\0\0\x30\x05\0\0\
\x84\0\0\0\x80\x03\0\0\x38\x05\0\0\x92\0\0\0\x80\x04\0\0\x3f\x05\0\0\x94\0\0\0\
\xc0\x04\0\0\x44\x05\0\0\x2b\0\0\0\xc0\x05\0\0\x4e\x05\0\0\x48\0\0\0\0\x06\0\0\
\x59\x05\0\0\x48\0\0\0\x40\x06\0\0\x66\x05\0\0\x95\0\0\0\x80\x06\0\0\x6b\x05\0\
\0\x96\0\0\0\xc0\x06\0\0\x75\x05\0\0\x97\0\0\0\0\x07\0\0\x7e\x05\0\0\x97\0\0\0\
\x20\x07\0\0\0\0\0\0\x02\0\0\x05\x10\0\0\0\x87\x05\0\0\x72\0\0\0\0\0\0\0\x90\
\x05\0\0\x52\0\0\0\0\0\0\0\x9b\x05\0\0\x01\0\0\x04\x08\0\0\0\x8a\x01\0\0\x73\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x72\0\0\0\xa6\x05\0\0\x02\0\0\x04\x10\0\0\0\xab\
\x05\0\0\x75\0\0\0\0\0\0\0\xc3\0\0\0\x26\0\0\0\x40\0\0\0\0\0\0\0\0\0\0\x02\xa0\
\0\0\0\0\0\0\0\0\0\0\x02\x77\0\0\0\0\0\0\0\0\0\0\x0a\xa2\0\0\0\xaf\x05\0\0\0\0\
\0\x08\x79\0\0\0\xbd\x05\0\0\0\0\0\x08\x7a\0\0\0\0\0\0\0\x01\0\0\x04\x08\0\0\0\
\x42\x02\0\0\x7b\0\0\0\0\0\0\0\xc8\x05\0\0\0\0\0\x08\x7c\0\0\0\xcc\x05\0\0\0\0\
\0\x08\x7d\0\0\0\xd2\x05\0\0\0\0\0\x01\x08\0\0\0\x40\0\0\x01\xdc\x05\0\0\0\0\0\
\x08\x0c\0\0\0\xe4\x05\0\0\x04\0\0\x04\x20\0\0\0\xea\x05\0\0\x78\0\0\0\0\0\0\0\
\xf0\x05\0\0\x80\0\0\0\x40\0\0\0\xfa\x05\0\0\x81\0\0\0\x60\0\0\0\xfe\x05\0\0\
\x4a\0\0\0\x80\0\0\0\x08\x06\0\0\0\0\0\x08\x37\0\0\0\x17\x06\0\0\x01\0\0\x04\
\x04\0\0\0\x70\x02\0\0\x3b\0\0\0\0\0\0\0\x2d\x06\0\0\0\0\0\x08\x83\0\0\0\x34\
\x06\0\0\0\0\0\x08\x7d\0\0\0\x44\x06\0\0\x06\0\0\x04\x20\0\0\0\xe0\x01\0\0\x85\
\0\0\0\0\0\0\0\x50\x06\0\0\x8c\0\0\0\x40\0\0\0\x54\x06\0\0\x8d\0\0\0\x80\0\0\0\
\x5d\x06\0\0\x8e\0\0\0\xa0\0\0\0\x61\x06\0\0\x8e\0\0\0\xc0\0\0\0\x66\x06\0\0\
\x02\0\0\0\xe0\0\0\0\x6d\x06\0\0\0\0\0\x08\x86\0\0\0\0\0\0\0\x01\0\0\x04\x08\0\
\0\0\x12\x02\0\0\x87\0\0\0\0\0\0\0\x76\x06\0\0\0\0\0\x08\x88\0\0\0\x84\x06\0\0\
\x02\0\0\x04\x08\0\0\0\0\0\0\0\x89\0\0\0\0\0\0\0\xf0\x05\0\0\x38\0\0\0\x20\0\0\
\0\0\0\0\0\x02\0\0\x05\x04\0\0\0\x8c\x06\0\0\x3b\0\0\0\0\0\0\0\0\0\0\0\x8a\0\0\
\0\0\0\0\0\0\0\0\0\x02\0\0\x04\x04\0\0\0\x91\x06\0\0\x3e\0\0\0\0\0\0\0\x99\x06\
\0\0\x8b\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\0\x3e\0\0\0\x04\0\0\0\x03\0\0\
\0\0\0\0\0\0\0\0\x02\xa9\0\0\0\x54\x06\0\0\x05\0\0\x06\x04\0\0\0\xa2\x06\0\0\0\
\0\0\0\xae\x06\0\0\x01\0\0\0\xbb\x06\0\0\x02\0\0\0\xc8\x06\0\0\x03\0\0\0\xd4\
\x06\0\0\x04\0\0\0\xe0\x06\0\0\0\0\0\x08\x8f\0\0\0\0\0\0\0\x01\0\0\x04\x04\0\0\
\0\x35\x02\0\0\x90\0\0\0\0\0\0\0\xe7\x06\0\0\0\0\0\x08\x91\0\0\0\xed\x06\0\0\0\
\0\0\x08\x0c\0\0\0\0\0\0\0\0\0\0\x02\x93\0\0\0\0\0\0\0\0\0\0\x0a\xa5\0\0\0\xfe\
\x06\0\0\x06\0\0\x04\x20\0\0\0\x0c\x07\0\0\x47\0\0\0\0\0\0\0\x12\x07\0\0\x0c\0\
\0\0\x40\0\0\0\x17\x07\0\0\x0c\0\0\0\x60\0\0\0\x22\x07\0\0\x0c\0\0\0\x80\0\0\0\
\x2b\x07\0\0\x0c\0\0\0\xa0\0\0\0\x35\x07\0\0\x82\0\0\0\xc0\0\0\0\0\0\0\0\0\0\0\
\x02\xa6\0\0\0\0\0\0\0\0\0\0\x02\x9f\0\0\0\x3e\x07\0\0\0\0\0\x08\x2a\0\0\0\0\0\
\0\0\0\0\0\x03\0\0\0\0\x6c\0\0\0\x04\0\0\0\x04\0\0\0\x47\x07\0\0\0\0\0\x0e\x98\
\0\0\0\x01\0\0\0\x50\x07\0\0\0\0\0\x0e\x02\0\0\0\x01\0\0\0\x5e\x07\0\0\0\0\0\
\x0e\x02\0\0\0\x01\0\0\0\x73\x07\0\0\0\0\0\x0e\x02\0\0\0\x01\0\0\0\x85\x07\0\0\
\0\0\0\x07\0\0\0\0\x8b\x07\0\0\0\0\0\x07\0\0\0\0\x9d\x07\0\0\0\0\0\x07\0\0\0\0\
\xab\x07\0\0\0\0\0\x07\0\0\0\0\xb4\x07\0\0\0\0\0\x07\0\0\0\0\xc0\x07\0\0\0\0\0\
\x07\0\0\0\0\xd0\x07\0\0\0\0\0\x07\0\0\0\0\xda\x07\0\0\0\0\0\x07\0\0\0\0\x59\
\x04\0\0\0\0\0\x07\0\0\0\0\xe9\x07\0\0\0\0\0\x07\0\0\0\0\xf4\x07\0\0\0\0\0\x07\
\0\0\0\0\x02\x08\0\0\0\0\0\x07\0\0\0\0\x50\x06\0\0\0\0\0\x07\0\0\0\0\x07\x08\0\
\0\0\0\0\x07\0\0\0\0\x57\x0e\0\0\x01\0\0\x0f\x04\0\0\0\x99\0\0\0\0\0\0\0\x04\0\
\0\0\x5f\x0e\0\0\x01\0\0\x0f\x04\0\0\0\x9a\0\0\0\0\0\0\0\x04\0\0\0\x64\x0e\0\0\
\x02\0\0\x0f\x08\0\0\0\x9b\0\0\0\0\0\0\0\x04\0\0\0\x9c\0\0\0\x04\0\0\0\x04\0\0\
\0\x6a\x0e\0\0\x04\0\0\x0f\x80\0\0\0\x0e\0\0\0\0\0\0\0\x20\0\0\0\x14\0\0\0\x20\
\0\0\0\x20\0\0\0\x15\0\0\0\x40\0\0\0\x20\0\0\0\x19\0\0\0\x60\0\0\0\x20\0\0\0\0\
\x69\x6e\x74\0\x5f\x5f\x41\x52\x52\x41\x59\x5f\x53\x49\x5a\x45\x5f\x54\x59\x50\
\x45\x5f\x5f\0\x6c\x6f\x63\x61\x6c\x5f\x73\x74\x6f\x72\x61\x67\x65\0\x65\x78\
\x65\x63\x5f\x69\x6e\x6f\x64\x65\0\x76\x61\x6c\x75\x65\0\x5f\x5f\x75\x33\x32\0\
\x75\x6e\x73\x69\x67\x6e\x65\x64\x20\x69\x6e\x74\0\x74\x79\x70\x65\0\x6d\x61\
\x70\x5f\x66\x6c\x61\x67\x73\0\x6b\x65\x79\0\x69\x6e\x6f\x64\x65\x5f\x73\x74\
\x6f\x72\x61\x67\x65\x5f\x6d\x61\x70\0\x73\x6b\x5f\x73\x74\x6f\x72\x61\x67\x65\
\x5f\x6d\x61\x70\0\x73\x6b\x5f\x73\x74\x6f\x72\x61\x67\x65\x5f\x6d\x61\x70\x32\
\0\x74\x61\x73\x6b\x5f\x73\x74\x6f\x72\x61\x67\x65\x5f\x6d\x61\x70\0\x75\x6e\
\x73\x69\x67\x6e\x65\x64\x20\x6c\x6f\x6e\x67\x20\x6c\x6f\x6e\x67\0\x63\x74\x78\
\0\x75\x6e\x6c\x69\x6e\x6b\x5f\x68\x6f\x6f\x6b\0\x64\x65\x6e\x74\x72\x79\0\x64\
\x5f\x66\x6c\x61\x67\x73\0\x64\x5f\x73\x65\x71\0\x64\x5f\x68\x61\x73\x68\0\x64\
\x5f\x70\x61\x72\x65\x6e\x74\0\x64\x5f\x6e\x61\x6d\x65\0\x64\x5f\x69\x6e\x6f\
\x64\x65\0\x64\x5f\x69\x6e\x61\x6d\x65\0\x64\x5f\x6c\x6f\x63\x6b\x72\x65\x66\0\
\x64\x5f\x6f\x70\0\x64\x5f\x73\x62\0\x64\x5f\x74\x69\x6d\x65\0\x64\x5f\x66\x73\
\x64\x61\x74\x61\0\x64\x5f\x63\x68\x69\x6c\x64\0\x64\x5f\x73\x75\x62\x64\x69\
\x72\x73\0\x64\x5f\x75\0\x73\x65\x71\x63\x6f\x75\x6e\x74\x5f\x73\x70\x69\x6e\
\x6c\x6f\x63\x6b\x5f\x74\0\x73\x65\x71\x63\x6f\x75\x6e\x74\x5f\x73\x70\x69\x6e\
\x6c\x6f\x63\x6b\0\x73\x65\x71\x63\x6f\x75\x6e\x74\0\x73\x65\x71\x63\x6f\x75\
\x6e\x74\x5f\x74\0\x73\x65\x71\x75\x65\x6e\x63\x65\0\x68\x6c\x69\x73\x74\x5f\
\x62\x6c\x5f\x6e\x6f\x64\x65\0\x6e\x65\x78\x74\0\x70\x70\x72\x65\x76\0\x71\x73\
\x74\x72\0\x6e\x61\x6d\x65\0\x68\x61\x73\x68\x5f\x6c\x65\x6e\0\x68\x61\x73\x68\
\0\x6c\x65\x6e\0\x75\x33\x32\0\x75\x36\x34\0\x5f\x5f\x75\x36\x34\0\x75\x6e\x73\
\x69\x67\x6e\x65\x64\x20\x63\x68\x61\x72\0\x6c\x6f\x63\x6b\x72\x65\x66\0\x6c\
\x6f\x63\x6b\x5f\x63\x6f\x75\x6e\x74\0\x6c\x6f\x63\x6b\0\x63\x6f\x75\x6e\x74\0\
\x73\x70\x69\x6e\x6c\x6f\x63\x6b\x5f\x74\0\x73\x70\x69\x6e\x6c\x6f\x63\x6b\0\
\x72\x6c\x6f\x63\x6b\0\x72\x61\x77\x5f\x73\x70\x69\x6e\x6c\x6f\x63\x6b\0\x72\
\x61\x77\x5f\x6c\x6f\x63\x6b\0\x61\x72\x63\x68\x5f\x73\x70\x69\x6e\x6c\x6f\x63\
\x6b\x5f\x74\0\x71\x73\x70\x69\x6e\x6c\x6f\x63\x6b\0\x76\x61\x6c\0\x61\x74\x6f\
\x6d\x69\x63\x5f\x74\0\x63\x6f\x75\x6e\x74\x65\x72\0\x6c\x6f\x63\x6b\x65\x64\0\
\x70\x65\x6e\x64\x69\x6e\x67\0\x75\x38\0\x5f\x5f\x75\x38\0\x6c\x6f\x63\x6b\x65\
\x64\x5f\x70\x65\x6e\x64\x69\x6e\x67\0\x74\x61\x69\x6c\0\x75\x31\x36\0\x5f\x5f\
\x75\x31\x36\0\x75\x6e\x73\x69\x67\x6e\x65\x64\x20\x73\x68\x6f\x72\x74\0\x75\
\x6e\x73\x69\x67\x6e\x65\x64\x20\x6c\x6f\x6e\x67\0\x64\x5f\x6c\x72\x75\0\x64\
\x5f\x77\x61\x69\x74\0\x6c\x69\x73\x74\x5f\x68\x65\x61\x64\0\x70\x72\x65\x76\0\
\x77\x61\x69\x74\x5f\x71\x75\x65\x75\x65\x5f\x68\x65\x61\x64\x5f\x74\0\x64\x5f\
\x61\x6c\x69\x61\x73\0\x64\x5f\x69\x6e\x5f\x6c\x6f\x6f\x6b\x75\x70\x5f\x68\x61\
\x73\x68\0\x64\x5f\x72\x63\x75\0\x68\x6c\x69\x73\x74\x5f\x6e\x6f\x64\x65\0\x63\
\x61\x6c\x6c\x62\x61\x63\x6b\x5f\x68\x65\x61\x64\0\x66\x75\x6e\x63\0\x69\x6e\
\x6f\x64\x65\x5f\x72\x65\x6e\x61\x6d\x65\0\x73\x6f\x63\x6b\x65\x74\x5f\x62\x69\
\x6e\x64\0\x73\x6f\x63\x6b\x65\x74\0\x73\x74\x61\x74\x65\0\x66\x6c\x61\x67\x73\
\0\x66\x69\x6c\x65\0\x73\x6b\0\x6f\x70\x73\0\x77\x71\0\x73\x6f\x63\x6b\x65\x74\
\x5f\x73\x74\x61\x74\x65\0\x53\x53\x5f\x46\x52\x45\x45\0\x53\x53\x5f\x55\x4e\
\x43\x4f\x4e\x4e\x45\x43\x54\x45\x44\0\x53\x53\x5f\x43\x4f\x4e\x4e\x45\x43\x54\
\x49\x4e\x47\0\x53\x53\x5f\x43\x4f\x4e\x4e\x45\x43\x54\x45\x44\0\x53\x53\x5f\
\x44\x49\x53\x43\x4f\x4e\x4e\x45\x43\x54\x49\x4e\x47\0\x73\x68\x6f\x72\x74\0\
\x73\x6f\x63\x6b\x65\x74\x5f\x77\x71\0\x77\x61\x69\x74\0\x66\x61\x73\x79\x6e\
\x63\x5f\x6c\x69\x73\x74\0\x72\x63\x75\0\x77\x61\x69\x74\x5f\x71\x75\x65\x75\
\x65\x5f\x68\x65\x61\x64\0\x68\x65\x61\x64\0\x73\x6f\x63\x6b\x65\x74\x5f\x70\
\x6f\x73\x74\x5f\x63\x72\x65\x61\x74\x65\0\x65\x78\x65\x63\0\x6c\x69\x6e\x75\
\x78\x5f\x62\x69\x6e\x70\x72\x6d\0\x76\x6d\x61\0\x76\x6d\x61\x5f\x70\x61\x67\
\x65\x73\0\x6d\x6d\0\x70\0\x61\x72\x67\x6d\x69\x6e\0\x68\x61\x76\x65\x5f\x65\
\x78\x65\x63\x66\x64\0\x65\x78\x65\x63\x66\x64\x5f\x63\x72\x65\x64\x73\0\x73\
\x65\x63\x75\x72\x65\x65\x78\x65\x63\0\x70\x6f\x69\x6e\x74\x5f\x6f\x66\x5f\x6e\
\x6f\x5f\x72\x65\x74\x75\x72\x6e\0\x65\x78\x65\x63\x75\x74\x61\x62\x6c\x65\0\
\x69\x6e\x74\x65\x72\x70\x72\x65\x74\x65\x72\0\x63\x72\x65\x64\0\x75\x6e\x73\
\x61\x66\x65\0\x70\x65\x72\x5f\x63\x6c\x65\x61\x72\0\x61\x72\x67\x63\0\x65\x6e\
\x76\x63\0\x66\x69\x6c\x65\x6e\x61\x6d\x65\0\x69\x6e\x74\x65\x72\x70\0\x66\x64\
\x70\x61\x74\x68\0\x69\x6e\x74\x65\x72\x70\x5f\x66\x6c\x61\x67\x73\0\x65\x78\
\x65\x63\x66\x64\0\x6c\x6f\x61\x64\x65\x72\0\x72\x6c\x69\x6d\x5f\x73\x74\x61\
\x63\x6b\0\x62\x75\x66\0\x63\x68\x61\x72\0\x72\x6c\x69\x6d\x69\x74\0\x72\x6c\
\x69\x6d\x5f\x63\x75\x72\0\x72\x6c\x69\x6d\x5f\x6d\x61\x78\0\x5f\x5f\x6b\x65\
\x72\x6e\x65\x6c\x5f\x75\x6c\x6f\x6e\x67\x5f\x74\0\x66\x5f\x75\0\x66\x5f\x70\
\x61\x74\x68\0\x66\x5f\x69\x6e\x6f\x64\x65\0\x66\x5f\x6f\x70\0\x66\x5f\x6c\x6f\
\x63\x6b\0\x66\x5f\x63\x6f\x75\x6e\x74\0\x66\x5f\x66\x6c\x61\x67\x73\0\x66\x5f\
\x6d\x6f\x64\x65\0\x66\x5f\x70\x6f\x73\x5f\x6c\x6f\x63\x6b\0\x66\x5f\x70\x6f\
\x73\0\x66\x5f\x6f\x77\x6e\x65\x72\0\x66\x5f\x63\x72\x65\x64\0\x66\x5f\x72\x61\
\0\x66\x5f\x76\x65\x72\x73\x69\x6f\x6e\0\x66\x5f\x73\x65\x63\x75\x72\x69\x74\
\x79\0\x70\x72\x69\x76\x61\x74\x65\x5f\x64\x61\x74\x61\0\x66\x5f\x65\x70\0\x66\
\x5f\x6d\x61\x70\x70\x69\x6e\x67\0\x66\x5f\x77\x62\x5f\x65\x72\x72\0\x66\x5f\
\x73\x62\x5f\x65\x72\x72\0\x66\x75\x5f\x6c\x6c\x69\x73\x74\0\x66\x75\x5f\x72\
\x63\x75\x68\x65\x61\x64\0\x6c\x6c\x69\x73\x74\x5f\x6e\x6f\x64\x65\0\x70\x61\
\x74\x68\0\x6d\x6e\x74\0\x61\x74\x6f\x6d\x69\x63\x5f\x6c\x6f\x6e\x67\x5f\x74\0\
\x61\x74\x6f\x6d\x69\x63\x36\x34\x5f\x74\0\x73\x36\x34\0\x5f\x5f\x73\x36\x34\0\
\x6c\x6f\x6e\x67\x20\x6c\x6f\x6e\x67\0\x66\x6d\x6f\x64\x65\x5f\x74\0\x6d\x75\
\x74\x65\x78\0\x6f\x77\x6e\x65\x72\0\x77\x61\x69\x74\x5f\x6c\x6f\x63\x6b\0\x6f\
\x73\x71\0\x77\x61\x69\x74\x5f\x6c\x69\x73\x74\0\x72\x61\x77\x5f\x73\x70\x69\
\x6e\x6c\x6f\x63\x6b\x5f\x74\0\x6f\x70\x74\x69\x6d\x69\x73\x74\x69\x63\x5f\x73\
\x70\x69\x6e\x5f\x71\x75\x65\x75\x65\0\x6c\x6f\x66\x66\x5f\x74\0\x5f\x5f\x6b\
\x65\x72\x6e\x65\x6c\x5f\x6c\x6f\x66\x66\x5f\x74\0\x66\x6f\x77\x6e\x5f\x73\x74\
\x72\x75\x63\x74\0\x70\x69\x64\0\x70\x69\x64\x5f\x74\x79\x70\x65\0\x75\x69\x64\
\0\x65\x75\x69\x64\0\x73\x69\x67\x6e\x75\x6d\0\x72\x77\x6c\x6f\x63\x6b\x5f\x74\
\0\x61\x72\x63\x68\x5f\x72\x77\x6c\x6f\x63\x6b\x5f\x74\0\x71\x72\x77\x6c\x6f\
\x63\x6b\0\x63\x6e\x74\x73\0\x77\x6c\x6f\x63\x6b\x65\x64\0\x5f\x5f\x6c\x73\x74\
\x61\x74\x65\0\x50\x49\x44\x54\x59\x50\x45\x5f\x50\x49\x44\0\x50\x49\x44\x54\
\x59\x50\x45\x5f\x54\x47\x49\x44\0\x50\x49\x44\x54\x59\x50\x45\x5f\x50\x47\x49\
\x44\0\x50\x49\x44\x54\x59\x50\x45\x5f\x53\x49\x44\0\x50\x49\x44\x54\x59\x50\
\x45\x5f\x4d\x41\x58\0\x6b\x75\x69\x64\x5f\x74\0\x75\x69\x64\x5f\x74\0\x5f\x5f\
\x6b\x65\x72\x6e\x65\x6c\x5f\x75\x69\x64\x33\x32\x5f\x74\0\x66\x69\x6c\x65\x5f\
\x72\x61\x5f\x73\x74\x61\x74\x65\0\x73\x74\x61\x72\x74\0\x73\x69\x7a\x65\0\x61\
\x73\x79\x6e\x63\x5f\x73\x69\x7a\x65\0\x72\x61\x5f\x70\x61\x67\x65\x73\0\x6d\
\x6d\x61\x70\x5f\x6d\x69\x73\x73\0\x70\x72\x65\x76\x5f\x70\x6f\x73\0\x65\x72\
\x72\x73\x65\x71\x5f\x74\0\x5f\x6c\x69\x63\x65\x6e\x73\x65\0\x6d\x6f\x6e\x69\
\x74\x6f\x72\x65\x64\x5f\x70\x69\x64\0\x69\x6e\x6f\x64\x65\x5f\x73\x74\x6f\x72\
\x61\x67\x65\x5f\x72\x65\x73\x75\x6c\x74\0\x73\x6b\x5f\x73\x74\x6f\x72\x61\x67\
\x65\x5f\x72\x65\x73\x75\x6c\x74\0\x69\x6e\x6f\x64\x65\0\x64\x65\x6e\x74\x72\
\x79\x5f\x6f\x70\x65\x72\x61\x74\x69\x6f\x6e\x73\0\x61\x64\x64\x72\x65\x73\x73\
\x5f\x73\x70\x61\x63\x65\0\x76\x66\x73\x6d\x6f\x75\x6e\x74\0\x73\x75\x70\x65\
\x72\x5f\x62\x6c\x6f\x63\x6b\0\x66\x69\x6c\x65\x5f\x6f\x70\x65\x72\x61\x74\x69\
\x6f\x6e\x73\0\x6d\x6d\x5f\x73\x74\x72\x75\x63\x74\0\x76\x6d\x5f\x61\x72\x65\
\x61\x5f\x73\x74\x72\x75\x63\x74\0\x68\x6c\x69\x73\x74\x5f\x68\x65\x61\x64\0\
\x66\x61\x73\x79\x6e\x63\x5f\x73\x74\x72\x75\x63\x74\0\x73\x6f\x63\x6b\0\x70\
\x72\x6f\x74\x6f\x5f\x6f\x70\x73\0\x2f\x62\x75\x69\x6c\x64\x64\x69\x72\x2f\x62\
\x75\x69\x6c\x64\x2f\x42\x55\x49\x4c\x44\x2f\x6b\x65\x72\x6e\x65\x6c\x2d\x35\
\x2e\x31\x34\x2e\x30\x2d\x33\x37\x32\x2e\x65\x6c\x39\x2f\x6c\x69\x6e\x75\x78\
\x2d\x35\x2e\x31\x34\x2e\x30\x2d\x33\x37\x32\x2e\x65\x6c\x39\x2e\x70\x70\x63\
\x36\x34\x6c\x65\x2f\x74\x6f\x6f\x6c\x73\x2f\x74\x65\x73\x74\x69\x6e\x67\x2f\
\x73\x65\x6c\x66\x74\x65\x73\x74\x73\x2f\x62\x70\x66\x2f\x70\x72\x6f\x67\x73\
\x2f\x6c\x6f\x63\x61\x6c\x5f\x73\x74\x6f\x72\x61\x67\x65\x2e\x63\0\x69\x6e\x74\
\x20\x42\x50\x46\x5f\x50\x52\x4f\x47\x28\x75\x6e\x6c\x69\x6e\x6b\x5f\x68\x6f\
\x6f\x6b\x2c\x20\x73\x74\x72\x75\x63\x74\x20\x69\x6e\x6f\x64\x65\x20\x2a\x64\
\x69\x72\x2c\x20\x73\x74\x72\x75\x63\x74\x20\x64\x65\x6e\x74\x72\x79\x20\x2a\
\x76\x69\x63\x74\x69\x6d\x29\0\x09\x5f\x5f\x75\x33\x32\x20\x70\x69\x64\x20\x3d\
\x20\x62\x70\x66\x5f\x67\x65\x74\x5f\x63\x75\x72\x72\x65\x6e\x74\x5f\x70\x69\
\x64\x5f\x74\x67\x69\x64\x28\x29\x20\x3e\x3e\x20\x33\x32\x3b\0\x09\x69\x66\x20\
\x28\x70\x69\x64\x20\x21\x3d\x20\x6d\x6f\x6e\x69\x74\x6f\x72\x65\x64\x5f\x70\
\x69\x64\x29\0\x09\x09\x09\x09\x20\x20\x20\x20\x20\x20\x20\x62\x70\x66\x5f\x67\
\x65\x74\x5f\x63\x75\x72\x72\x65\x6e\x74\x5f\x74\x61\x73\x6b\x5f\x62\x74\x66\
\x28\x29\x2c\x20\x30\x2c\x20\x30\x29\x3b\0\x09\x73\x74\x6f\x72\x61\x67\x65\x20\
\x3d\x20\x62\x70\x66\x5f\x74\x61\x73\x6b\x5f\x73\x74\x6f\x72\x61\x67\x65\x5f\
\x67\x65\x74\x28\x26\x74\x61\x73\x6b\x5f\x73\x74\x6f\x72\x61\x67\x65\x5f\x6d\
\x61\x70\x2c\0\x09\x69\x66\x20\x28\x73\x74\x6f\x72\x61\x67\x65\x29\x20\x7b\0\
\x09\x09\x69\x73\x5f\x73\x65\x6c\x66\x5f\x75\x6e\x6c\x69\x6e\x6b\x20\x3d\x20\
\x73\x74\x6f\x72\x61\x67\x65\x2d\x3e\x65\x78\x65\x63\x5f\x69\x6e\x6f\x64\x65\
\x20\x3d\x3d\x20\x76\x69\x63\x74\x69\x6d\x2d\x3e\x64\x5f\x69\x6e\x6f\x64\x65\
\x3b\0\x09\x09\x69\x66\x20\x28\x69\x73\x5f\x73\x65\x6c\x66\x5f\x75\x6e\x6c\x69\
\x6e\x6b\x29\0\x69\x6e\x74\x20\x42\x50\x46\x5f\x50\x52\x4f\x47\x28\x69\x6e\x6f\
\x64\x65\x5f\x72\x65\x6e\x61\x6d\x65\x2c\x20\x73\x74\x72\x75\x63\x74\x20\x69\
\x6e\x6f\x64\x65\x20\x2a\x6f\x6c\x64\x5f\x64\x69\x72\x2c\x20\x73\x74\x72\x75\
\x63\x74\x20\x64\x65\x6e\x74\x72\x79\x20\x2a\x6f\x6c\x64\x5f\x64\x65\x6e\x74\
\x72\x79\x2c\0\x09\x62\x70\x66\x5f\x69\x6e\x6f\x64\x65\x5f\x73\x74\x6f\x72\x61\
\x67\x65\x5f\x67\x65\x74\x28\x26\x69\x6e\x6f\x64\x65\x5f\x73\x74\x6f\x72\x61\
\x67\x65\x5f\x6d\x61\x70\x2c\x20\x6e\x65\x77\x5f\x64\x65\x6e\x74\x72\x79\x2d\
\x3e\x64\x5f\x69\x6e\x6f\x64\x65\x2c\x20\x30\x2c\0\x09\x73\x74\x6f\x72\x61\x67\
\x65\x20\x3d\x20\x62\x70\x66\x5f\x69\x6e\x6f\x64\x65\x5f\x73\x74\x6f\x72\x61\
\x67\x65\x5f\x67\x65\x74\x28\x26\x69\x6e\x6f\x64\x65\x5f\x73\x74\x6f\x72\x61\
\x67\x65\x5f\x6d\x61\x70\x2c\x20\x6f\x6c\x64\x5f\x64\x65\x6e\x74\x72\x79\x2d\
\x3e\x64\x5f\x69\x6e\x6f\x64\x65\x2c\0\x09\x69\x66\x20\x28\x21\x73\x74\x6f\x72\
\x61\x67\x65\x29\0\x09\x69\x66\x20\x28\x73\x74\x6f\x72\x61\x67\x65\x2d\x3e\x76\
\x61\x6c\x75\x65\x20\x21\x3d\x20\x44\x55\x4d\x4d\x59\x5f\x53\x54\x4f\x52\x41\
\x47\x45\x5f\x56\x41\x4c\x55\x45\x29\0\x09\x09\x69\x6e\x6f\x64\x65\x5f\x73\x74\
\x6f\x72\x61\x67\x65\x5f\x72\x65\x73\x75\x6c\x74\x20\x3d\x20\x2d\x31\x3b\0\x09\
\x65\x72\x72\x20\x3d\x20\x62\x70\x66\x5f\x69\x6e\x6f\x64\x65\x5f\x73\x74\x6f\
\x72\x61\x67\x65\x5f\x64\x65\x6c\x65\x74\x65\x28\x26\x69\x6e\x6f\x64\x65\x5f\
\x73\x74\x6f\x72\x61\x67\x65\x5f\x6d\x61\x70\x2c\x20\x6f\x6c\x64\x5f\x64\x65\
\x6e\x74\x72\x79\x2d\x3e\x64\x5f\x69\x6e\x6f\x64\x65\x29\x3b\0\x09\x69\x66\x20\
\x28\x21\x65\x72\x72\x29\0\x09\x09\x69\x6e\x6f\x64\x65\x5f\x73\x74\x6f\x72\x61\
\x67\x65\x5f\x72\x65\x73\x75\x6c\x74\x20\x3d\x20\x65\x72\x72\x3b\0\x69\x6e\x74\
\x20\x42\x50\x46\x5f\x50\x52\x4f\x47\x28\x73\x6f\x63\x6b\x65\x74\x5f\x62\x69\
\x6e\x64\x2c\x20\x73\x74\x72\x75\x63\x74\x20\x73\x6f\x63\x6b\x65\x74\x20\x2a\
\x73\x6f\x63\x6b\x2c\x20\x73\x74\x72\x75\x63\x74\x20\x73\x6f\x63\x6b\x61\x64\
\x64\x72\x20\x2a\x61\x64\x64\x72\x65\x73\x73\x2c\0\x09\x73\x74\x6f\x72\x61\x67\
\x65\x20\x3d\x20\x62\x70\x66\x5f\x73\x6b\x5f\x73\x74\x6f\x72\x61\x67\x65\x5f\
\x67\x65\x74\x28\x26\x73\x6b\x5f\x73\x74\x6f\x72\x61\x67\x65\x5f\x6d\x61\x70\
\x2c\x20\x73\x6f\x63\x6b\x2d\x3e\x73\x6b\x2c\x20\x30\x2c\0\x09\x09\x73\x6b\x5f\
\x73\x74\x6f\x72\x61\x67\x65\x5f\x72\x65\x73\x75\x6c\x74\x20\x3d\x20\x2d\x31\
\x3b\0\x09\x73\x74\x6f\x72\x61\x67\x65\x20\x3d\x20\x62\x70\x66\x5f\x73\x6b\x5f\
\x73\x74\x6f\x72\x61\x67\x65\x5f\x67\x65\x74\x28\x26\x73\x6b\x5f\x73\x74\x6f\
\x72\x61\x67\x65\x5f\x6d\x61\x70\x32\x2c\x20\x73\x6f\x63\x6b\x2d\x3e\x73\x6b\
\x2c\x20\x30\x2c\0\x09\x65\x72\x72\x20\x3d\x20\x62\x70\x66\x5f\x73\x6b\x5f\x73\
\x74\x6f\x72\x61\x67\x65\x5f\x64\x65\x6c\x65\x74\x65\x28\x26\x73\x6b\x5f\x73\
\x74\x6f\x72\x61\x67\x65\x5f\x6d\x61\x70\x2c\x20\x73\x6f\x63\x6b\x2d\x3e\x73\
\x6b\x29\x3b\0\x09\x69\x66\x20\x28\x65\x72\x72\x29\0\x09\x65\x72\x72\x20\x3d\
\x20\x62\x70\x66\x5f\x73\x6b\x5f\x73\x74\x6f\x72\x61\x67\x65\x5f\x64\x65\x6c\
\x65\x74\x65\x28\x26\x73\x6b\x5f\x73\x74\x6f\x72\x61\x67\x65\x5f\x6d\x61\x70\
\x32\x2c\x20\x73\x6f\x63\x6b\x2d\x3e\x73\x6b\x29\x3b\0\x09\x09\x73\x6b\x5f\x73\
\x74\x6f\x72\x61\x67\x65\x5f\x72\x65\x73\x75\x6c\x74\x20\x3d\x20\x65\x72\x72\
\x3b\0\x69\x6e\x74\x20\x42\x50\x46\x5f\x50\x52\x4f\x47\x28\x73\x6f\x63\x6b\x65\
\x74\x5f\x70\x6f\x73\x74\x5f\x63\x72\x65\x61\x74\x65\x2c\x20\x73\x74\x72\x75\
\x63\x74\x20\x73\x6f\x63\x6b\x65\x74\x20\x2a\x73\x6f\x63\x6b\x2c\x20\x69\x6e\
\x74\x20\x66\x61\x6d\x69\x6c\x79\x2c\x20\x69\x6e\x74\x20\x74\x79\x70\x65\x2c\0\
\x09\x73\x74\x6f\x72\x61\x67\x65\x2d\x3e\x76\x61\x6c\x75\x65\x20\x3d\x20\x44\
\x55\x4d\x4d\x59\x5f\x53\x54\x4f\x52\x41\x47\x45\x5f\x56\x41\x4c\x55\x45\x3b\0\
\x76\x6f\x69\x64\x20\x42\x50\x46\x5f\x50\x52\x4f\x47\x28\x65\x78\x65\x63\x2c\
\x20\x73\x74\x72\x75\x63\x74\x20\x6c\x69\x6e\x75\x78\x5f\x62\x69\x6e\x70\x72\
\x6d\x20\x2a\x62\x70\x72\x6d\x29\0\x09\x09\x09\x09\x20\x20\x20\x20\x20\x20\x20\
\x62\x70\x66\x5f\x67\x65\x74\x5f\x63\x75\x72\x72\x65\x6e\x74\x5f\x74\x61\x73\
\x6b\x5f\x62\x74\x66\x28\x29\x2c\x20\x30\x2c\0\x09\x69\x66\x20\x28\x73\x74\x6f\
\x72\x61\x67\x65\x29\0\x09\x09\x73\x74\x6f\x72\x61\x67\x65\x2d\x3e\x65\x78\x65\
\x63\x5f\x69\x6e\x6f\x64\x65\x20\x3d\x20\x62\x70\x72\x6d\x2d\x3e\x66\x69\x6c\
\x65\x2d\x3e\x66\x5f\x69\x6e\x6f\x64\x65\x3b\0\x09\x73\x74\x6f\x72\x61\x67\x65\
\x20\x3d\x20\x62\x70\x66\x5f\x69\x6e\x6f\x64\x65\x5f\x73\x74\x6f\x72\x61\x67\
\x65\x5f\x67\x65\x74\x28\x26\x69\x6e\x6f\x64\x65\x5f\x73\x74\x6f\x72\x61\x67\
\x65\x5f\x6d\x61\x70\x2c\x20\x62\x70\x72\x6d\x2d\x3e\x66\x69\x6c\x65\x2d\x3e\
\x66\x5f\x69\x6e\x6f\x64\x65\x2c\0\x30\x3a\x35\0\x30\x3a\x34\0\x30\x3a\x31\x31\
\0\x30\x3a\x32\0\x6c\x69\x63\x65\x6e\x73\x65\0\x2e\x62\x73\x73\0\x2e\x64\x61\
\x74\x61\0\x2e\x6d\x61\x70\x73\0\x6c\x73\x6d\x2f\x69\x6e\x6f\x64\x65\x5f\x75\
\x6e\x6c\x69\x6e\x6b\0\x6c\x73\x6d\x2e\x73\x2f\x69\x6e\x6f\x64\x65\x5f\x72\x65\
\x6e\x61\x6d\x65\0\x6c\x73\x6d\x2e\x73\x2f\x73\x6f\x63\x6b\x65\x74\x5f\x62\x69\
\x6e\x64\0\x6c\x73\x6d\x2e\x73\x2f\x73\x6f\x63\x6b\x65\x74\x5f\x70\x6f\x73\x74\
\x5f\x63\x72\x65\x61\x74\x65\0\x6c\x73\x6d\x2e\x73\x2f\x62\x70\x72\x6d\x5f\x63\
\x6f\x6d\x6d\x69\x74\x74\x65\x64\x5f\x63\x72\x65\x64\x73\0\0\0\x9f\xeb\x01\0\
\x20\0\0\0\0\0\0\0\x54\0\0\0\x54\0\0\0\x1c\x05\0\0\x70\x05\0\0\xfc\0\0\0\x08\0\
\0\0\x70\x0e\0\0\x01\0\0\0\0\0\0\0\x1d\0\0\0\x81\x0e\0\0\x01\0\0\0\0\0\0\0\x56\
\0\0\0\x94\x0e\0\0\x01\0\0\0\0\0\0\0\x57\0\0\0\xa6\x0e\0\0\x01\0\0\0\0\0\0\0\
\x63\0\0\0\xbf\x0e\0\0\x01\0\0\0\0\0\0\0\x65\0\0\0\x10\0\0\0\x70\x0e\0\0\x0d\0\
\0\0\0\0\0\0\x11\x08\0\0\x8c\x08\0\0\0\xd8\0\0\x08\0\0\0\x11\x08\0\0\x8c\x08\0\
\0\x05\xd8\0\0\x10\0\0\0\x11\x08\0\0\xd0\x08\0\0\x0e\xe0\0\0\x18\0\0\0\x11\x08\
\0\0\xd0\x08\0\0\x29\xe0\0\0\x20\0\0\0\x11\x08\0\0\xff\x08\0\0\x0d\xf0\0\0\x38\
\0\0\0\x11\x08\0\0\xff\x08\0\0\x06\xf0\0\0\x40\0\0\0\x11\x08\0\0\x1a\x09\0\0\
\x0c\0\x01\0\x48\0\0\0\x11\x08\0\0\x48\x09\0\0\x0c\xfc\0\0\x78\0\0\0\x11\x08\0\
\0\x7b\x09\0\0\x06\x04\x01\0\x90\0\0\0\x11\x08\0\0\x8b\x09\0\0\x33\x0c\x01\0\
\x98\0\0\0\x11\x08\0\0\x8b\x09\0\0\x1d\x0c\x01\0\xa0\0\0\0\x11\x08\0\0\xc6\x09\
\0\0\x07\x10\x01\0\xb0\0\0\0\x11\x08\0\0\x8c\x08\0\0\x05\xd8\0\0\x81\x0e\0\0\
\x0f\0\0\0\0\0\0\0\x11\x08\0\0\xdc\x09\0\0\x05\x30\x01\0\x10\0\0\0\x11\x08\0\0\
\xd0\x08\0\0\x0e\x40\x01\0\x18\0\0\0\x11\x08\0\0\x29\x0a\0\0\x38\x60\x01\0\x20\
\0\0\0\x11\x08\0\0\x29\x0a\0\0\x02\x60\x01\0\x48\0\0\0\x11\x08\0\0\x6c\x0a\0\0\
\x42\x6c\x01\0\x50\0\0\0\x11\x08\0\0\x6c\x0a\0\0\x0c\x6c\x01\0\x78\0\0\0\x11\
\x08\0\0\xb6\x0a\0\0\x06\x74\x01\0\x80\0\0\0\x11\x08\0\0\xc5\x0a\0\0\x0f\x80\
\x01\0\x98\0\0\0\x11\x08\0\0\xc5\x0a\0\0\x06\x80\x01\0\xa0\0\0\0\x11\x08\0\0\
\xf1\x0a\0\0\x18\x84\x01\0\xc8\0\0\0\x11\x08\0\0\x0e\x0b\0\0\x41\x8c\x01\0\xd0\
\0\0\0\x11\x08\0\0\x0e\x0b\0\0\x08\x8c\x01\0\xf8\0\0\0\x11\x08\0\0\x58\x0b\0\0\
\x06\x90\x01\0\0\x01\0\0\x11\x08\0\0\x63\x0b\0\0\x18\x94\x01\0\x20\x01\0\0\x11\
\x08\0\0\xdc\x09\0\0\x05\x30\x01\0\x94\x0e\0\0\x18\0\0\0\0\0\0\0\x11\x08\0\0\
\x81\x0b\0\0\x05\xac\x01\0\x08\0\0\0\x11\x08\0\0\xd0\x08\0\0\x0e\xb8\x01\0\x10\
\0\0\0\x11\x08\0\0\xd0\x08\0\0\x29\xb8\x01\0\x18\0\0\0\x11\x08\0\0\xff\x08\0\0\
\x0d\xc8\x01\0\x30\0\0\0\x11\x08\0\0\xff\x08\0\0\x06\xc8\x01\0\x38\0\0\0\x11\
\x08\0\0\xca\x0b\0\0\x36\xd4\x01\0\x40\0\0\0\x11\x08\0\0\xca\x0b\0\0\x0c\xd4\
\x01\0\x68\0\0\0\x11\x08\0\0\xb6\x0a\0\0\x06\xdc\x01\0\x70\0\0\0\x11\x08\0\0\
\xc5\x0a\0\0\x0f\xe8\x01\0\x88\0\0\0\x11\x08\0\0\xc5\x0a\0\0\x06\xe8\x01\0\x90\
\0\0\0\x11\x08\0\0\x06\x0c\0\0\x15\xec\x01\0\xb8\0\0\0\x11\x08\0\0\x20\x0c\0\0\
\x37\0\x02\0\xc0\0\0\0\x11\x08\0\0\x20\x0c\0\0\x0c\0\x02\0\xe8\0\0\0\x11\x08\0\
\0\xb6\x0a\0\0\x06\x08\x02\0\xf0\0\0\0\x11\x08\0\0\x5d\x0c\0\0\x35\x14\x02\0\
\xf8\0\0\0\x11\x08\0\0\x5d\x0c\0\0\x08\x14\x02\0\x10\x01\0\0\x11\x08\0\0\x96\
\x0c\0\0\x06\x18\x02\0\x20\x01\0\0\x11\x08\0\0\x96\x0c\0\0\x06\x18\x02\0\x28\
\x01\0\0\x11\x08\0\0\xa0\x0c\0\0\x36\x24\x02\0\x30\x01\0\0\x11\x08\0\0\xa0\x0c\
\0\0\x08\x24\x02\0\x48\x01\0\0\x11\x08\0\0\x58\x0b\0\0\x07\x28\x02\0\x58\x01\0\
\0\x11\x08\0\0\x58\x0b\0\0\x06\x28\x02\0\x60\x01\0\0\x11\x08\0\0\xda\x0c\0\0\
\x15\x2c\x02\0\x80\x01\0\0\x11\x08\0\0\x81\x0b\0\0\x05\xac\x01\0\xa6\x0e\0\0\
\x0a\0\0\0\0\0\0\0\x11\x08\0\0\xf5\x0c\0\0\x05\x44\x02\0\x08\0\0\0\x11\x08\0\0\
\xd0\x08\0\0\x0e\x50\x02\0\x10\0\0\0\x11\x08\0\0\xd0\x08\0\0\x29\x50\x02\0\x18\
\0\0\0\x11\x08\0\0\xff\x08\0\0\x0d\x5c\x02\0\x30\0\0\0\x11\x08\0\0\xff\x08\0\0\
\x06\x5c\x02\0\x38\0\0\0\x11\x08\0\0\xca\x0b\0\0\x36\x68\x02\0\x40\0\0\0\x11\
\x08\0\0\xca\x0b\0\0\x0c\x68\x02\0\x68\0\0\0\x11\x08\0\0\xb6\x0a\0\0\x06\x70\
\x02\0\x80\0\0\0\x11\x08\0\0\x41\x0d\0\0\x11\x7c\x02\0\x88\0\0\0\x11\x08\0\0\
\xf5\x0c\0\0\x05\x44\x02\0\xbf\x0e\0\0\x11\0\0\0\0\0\0\0\x11\x08\0\0\x68\x0d\0\
\0\x06\xa0\x02\0\x08\0\0\0\x11\x08\0\0\xd0\x08\0\0\x0e\xa8\x02\0\x10\0\0\0\x11\
\x08\0\0\xd0\x08\0\0\x29\xa8\x02\0\x18\0\0\0\x11\x08\0\0\xff\x08\0\0\x0d\xb4\
\x02\0\x30\0\0\0\x11\x08\0\0\xff\x08\0\0\x06\xb4\x02\0\x38\0\0\0\x11\x08\0\0\
\x97\x0d\0\0\x0c\xc4\x02\0\x40\0\0\0\x11\x08\0\0\x48\x09\0\0\x0c\xc0\x02\0\x70\
\0\0\0\x11\x08\0\0\xc1\x0d\0\0\x06\xcc\x02\0\x78\0\0\0\x11\x08\0\0\xcf\x0d\0\0\
\x1f\xd0\x02\0\x80\0\0\0\x11\x08\0\0\xcf\x0d\0\0\x25\xd0\x02\0\x88\0\0\0\x11\
\x08\0\0\xcf\x0d\0\0\x17\xd0\x02\0\x90\0\0\0\x11\x08\0\0\xfc\x0d\0\0\x3c\xd8\
\x02\0\x98\0\0\0\x11\x08\0\0\xfc\x0d\0\0\x42\xd8\x02\0\xa0\0\0\0\x11\x08\0\0\
\xfc\x0d\0\0\x0c\xd8\x02\0\xc8\0\0\0\x11\x08\0\0\xb6\x0a\0\0\x06\xe0\x02\0\xe0\
\0\0\0\x11\x08\0\0\x41\x0d\0\0\x11\xec\x02\0\xe8\0\0\0\x11\x08\0\0\x68\x0d\0\0\
\x06\xa0\x02\0\x10\0\0\0\x70\x0e\0\0\x01\0\0\0\x90\0\0\0\x1e\0\0\0\x46\x0e\0\0\
\0\0\0\0\x81\x0e\0\0\x03\0\0\0\x18\0\0\0\x1e\0\0\0\x46\x0e\0\0\0\0\0\0\x48\0\0\
\0\x1e\0\0\0\x46\x0e\0\0\0\0\0\0\xc8\0\0\0\x1e\0\0\0\x46\x0e\0\0\0\0\0\0\x94\
\x0e\0\0\x04\0\0\0\x38\0\0\0\x58\0\0\0\x4a\x0e\0\0\0\0\0\0\xb8\0\0\0\x58\0\0\0\
\x4a\x0e\0\0\0\0\0\0\xf0\0\0\0\x58\0\0\0\x4a\x0e\0\0\0\0\0\0\x28\x01\0\0\x58\0\
\0\0\x4a\x0e\0\0\0\0\0\0\xa6\x0e\0\0\x01\0\0\0\x38\0\0\0\x58\0\0\0\x4a\x0e\0\0\
\0\0\0\0\xbf\x0e\0\0\x04\0\0\0\x78\0\0\0\x66\0\0\0\x4e\x0e\0\0\0\0\0\0\x80\0\0\
\0\x70\0\0\0\x53\x0e\0\0\0\0\0\0\x90\0\0\0\x66\0\0\0\x4e\x0e\0\0\0\0\0\0\x98\0\
\0\0\x70\0\0\0\x53\x0e\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\x01\0\0\0\x03\0\0\0\x20\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x40\0\0\0\
\0\0\0\0\x2c\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x09\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x70\x02\0\0\0\0\0\0\xb8\
\x02\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\x18\0\0\0\0\0\0\0\x11\0\0\
\0\x01\0\0\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x28\x05\0\0\0\0\0\0\xc0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x22\0\0\0\x01\0\0\0\
\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xe8\x05\0\0\0\0\0\0\x30\x01\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x35\0\0\0\x01\0\0\0\x06\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\x18\x07\0\0\0\0\0\0\x90\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x47\0\0\0\x01\0\0\0\x06\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\xa8\x08\0\0\0\0\0\0\x98\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\x60\0\0\0\x01\0\0\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x40\
\x09\0\0\0\0\0\0\xf0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\x7b\0\0\0\x01\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x30\x0a\0\0\0\0\0\
\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x83\0\0\
\0\x08\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x34\x0a\0\0\0\0\0\0\x04\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x88\0\0\0\x01\0\0\0\
\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x34\x0a\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x8e\0\0\0\x01\0\0\0\x03\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\x40\x0a\0\0\0\0\0\0\x80\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xa0\x01\0\0\x09\0\0\0\x40\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\xc0\x0a\0\0\0\0\0\0\x20\0\0\0\0\0\0\0\x02\0\0\0\x03\0\0\0\x08\0\0\0\0\
\0\0\0\x10\0\0\0\0\0\0\0\xb5\x01\0\0\x09\0\0\0\x40\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\xe0\x0a\0\0\0\0\0\0\x50\0\0\0\0\0\0\0\x02\0\0\0\x04\0\0\0\x08\0\0\0\0\0\0\0\
\x10\0\0\0\0\0\0\0\xcc\x01\0\0\x09\0\0\0\x40\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x30\
\x0b\0\0\0\0\0\0\x70\0\0\0\0\0\0\0\x02\0\0\0\x05\0\0\0\x08\0\0\0\0\0\0\0\x10\0\
\0\0\0\0\0\0\xe2\x01\0\0\x09\0\0\0\x40\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xa0\x0b\0\
\0\0\0\0\0\x20\0\0\0\0\0\0\0\x02\0\0\0\x06\0\0\0\x08\0\0\0\0\0\0\0\x10\0\0\0\0\
\0\0\0\xff\x01\0\0\x09\0\0\0\x40\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xc0\x0b\0\0\0\0\
\0\0\x30\0\0\0\0\0\0\0\x02\0\0\0\x07\0\0\0\x08\0\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\
\x1e\x02\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xf0\x0b\0\0\0\0\0\0\x16\
\x20\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x23\x02\0\0\
\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\x2c\0\0\0\0\0\0\x8c\x06\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0";
}

#ifdef __cplusplus
struct local_storage *local_storage::open(const struct bpf_object_open_opts *opts) { return local_storage__open_opts(opts); }
struct local_storage *local_storage::open_and_load() { return local_storage__open_and_load(); }
int local_storage::load(struct local_storage *skel) { return local_storage__load(skel); }
int local_storage::attach(struct local_storage *skel) { return local_storage__attach(skel); }
void local_storage::detach(struct local_storage *skel) { local_storage__detach(skel); }
void local_storage::destroy(struct local_storage *skel) { local_storage__destroy(skel); }
const void *local_storage::elf_bytes(size_t *sz) { return local_storage__elf_bytes(sz); }
#endif /* __cplusplus */

__attribute__((unused)) static void
local_storage__assert(struct local_storage *s __attribute__((unused)))
{
#ifdef __cplusplus
#define _Static_assert static_assert
#endif
	_Static_assert(sizeof(s->bss->monitored_pid) == 4, "unexpected size of 'monitored_pid'");
	_Static_assert(sizeof(s->data->inode_storage_result) == 4, "unexpected size of 'inode_storage_result'");
	_Static_assert(sizeof(s->data->sk_storage_result) == 4, "unexpected size of 'sk_storage_result'");
#ifdef __cplusplus
#undef _Static_assert
#endif
}

#endif /* __LOCAL_STORAGE_SKEL_H__ */
